@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20130731';
+our $VERSION = '0.20130830';
 
-# Table last modified: 2013-07-31
+# Table last modified: 2013-08-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -67,11 +67,11 @@ our %ZIP_TABLE = (
     '061' => '(?:(?:1(?:49[236-8]|39[2356]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292))',
     '062' => '(?:8(?:6(?:55|86|0[1-357-9]|3[0135]|2[24]|4[12]|1[0278]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:6(?:0[1-36-8]|1[12]|4[15])|5(?:58|0[17]|[18][05])))',
-    '064' => '(?:8(?:5(?:2[0-46]|6[0-7]|4[0-356]|8[169]|0[23569]|7[0157]|3[035-7]|5[0-24-8]|1[02569])|6(?:09|86|2[0-2489]|4[4589]|1[01]|3[039])|798))',
+    '064' => '(?:8(?:5(?:2[0-46]|6[0-7]|4[0-356]|8[169]|0[23569]|7[0157]|3[035-7]|5[0-24-8]|1[02569])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:3[39]|0[19]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
-    '068' => '(?:(?:8(?:6(?:[03]9|42|50|6[06]|8[68])|5(?:88|5[058]))|1(?:19[2-5]|292)|0(?:194|492)|219[2-4]))',
+    '068' => '(?:(?:8(?:6(?:[03]9|42|50|6[068]|8[68])|5(?:88|5[058]))|1(?:19[2-5]|292)|0(?:194|492)|219[2-4]))',
     '069' => '(?:(?:1(?:29[236-8]|39[2-5])|85(?:[01]1|[58]5|33)|029[23]))',
     '070' => '(?:8(?:6(?:[02]1|6[06]|1[0-26]|5[013]|[78][068]|3[069]|4[0-24])|5(?:[35]0|[12][015]|0[2357]|6[07]|4[01])|7(?:01|2[02]|1[01])))',
     '071' => '(?:(?:0(?:19[28]|29[28]|59[67]|79[58])|1(?:49[2-7]|29[2358]|59[236])))',
@@ -80,9 +80,9 @@ our %ZIP_TABLE = (
     '074' => '(?:(?:8(?:6(?:50|86)|585)|049[2-5]))',
     '075' => '(?:8(?:50|71)1)',
     '076' => '(?:8(?:5(?:11|55)|6(?:09|66)|765))',
-    '077' => '(?:(?:8(?:5(?:[01]1|85)|6(?:01|60|86))|029[2356]))',
+    '077' => '(?:(?:8(?:6(?:01|60|86)|5[01]1)|029[2356]))',
     '078' => '(?:(?:1(?:79[235-7]|49[235]|39[35])|85(?:55|0[1-6]|1[013])|4(?:19[3468]|492)|3(?:39[2-4]|792)|2(?:19[23]|692)|039[27]))',
-    '079' => '(?:(?:8(?:5(?:0[1-357-9]|8[58]|5[05]|1[134689])|6(?:1[0-3]|5[0-356]))|0(?:39[2-47]|19[278]|59[235])|1(?:39[367]|192)))',
+    '079' => '(?:(?:8(?:5(?:0[1-357-9]|8[58]|5[05]|1[134689])|6(?:1[0-3]|5[0-256]))|0(?:39[2-47]|19[278]|59[235])|1(?:39[367]|192)))',
     '080' => '(?:(?:8(?:5(?:[67]0|0[1-3]|1[018]|8[58]|5[05]|3[18])|6(?:23|39|42|55|6[06]|0[19]|7[07]|8[068])|7(?:[01][18]))|249[235-8]|019[6-8]|149[23]))',
     '081' => '(?:(?:029[2-5]|8501))',
     '082' => '(?:865[01])',
@@ -91,7 +91,7 @@ our %ZIP_TABLE = (
     '085' => '(?:(?:8(?:5(?:67|1[0-25]|3[35]|2[27]|5[01578]|8[01568]|0[125])|6(?:[34]9|77|5[05]|6[08]))|029[23]))',
     '086' => '(?:1(?:89[23]|197))',
     '087' => '(?:(?:8(?:5(?:55|88)|6(?:09|86)|711)|0192))',
-    '088' => '(?:(?:0(?:39[2-5]|59[258]|19[23]|692)|1(?:19[2-5]|592)|3(?:292|395)|259[23]))',
+    '088' => '(?:(?:0(?:39[2-5]|59[258]|19[23]|692)|1(?:19[235]|592)|3(?:39[59]|292)|259[23]))',
     '089' => '(?:(?:1(?:19[28]|39[25]|59[25]|795)|0(?:19[258]|59[258]|69[23])|2(?:69[235-7]|195|492)|5(?:39[23]|69[25])|3(?:392|797)))',
     '090' => '(?:8(?:5(?:40|3[23]|[58][058]|6[07]|1[189]|0[1-379])|6(?:[18]0|42|66|5[025])|7(?:2[239]|1[01])))',
     '091' => '(?:(?:019[2-4]|8666))',
@@ -105,9 +105,9 @@ our %ZIP_TABLE = (
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[035])|101))',
-    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[45]|1[125689])|79[58]))',
+    '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[45]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-2589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[0-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|6[067]|3[13-8]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-8])|4(?:3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|1[05689]|2[0-59])|5(?:1[028]|3[035689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:4[04]|1[0-3579]|8[0368]|7[027]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-8])|4(?:3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|1[05689]|2[0-59])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|4[04]|1[0-3579]|8[01368]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
     '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|7[0-39]|4[015-9]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|3[0-257]|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[079]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
@@ -115,7 +115,7 @@ our %ZIP_TABLE = (
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[01357]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|0[1467]|2[02579]|4[24]|7[0178]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
+    '112' => '(?:8(?:6(?:90|0[1467]|2[02579]|4[24]|7[01578]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
     '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|7[147]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
@@ -124,16 +124,16 @@ our %ZIP_TABLE = (
     '121' => '(?:8(?:5(?:20|0[45]|8[58]|[15][05])|6(?:82|3[39]|1[01])|7(?:11|29)|080))',
     '123' => '(?:85(?:40|88|1[147]|0[135689]))',
     '124' => '(?:85(?:60|77|2[04]|3[3589]|0[1-39]|8[58]|5[05]|1[01]))',
-    '125' => '(?:8(?:5(?:55|1[1-57]|0[3-8]|8[58]|2[026])|601))',
+    '125' => '(?:8(?:5(?:1[1-57]|0[3-8]|8[58]|2[026])|601))',
     '130' => '(?:8(?:5(?:7[057]|8[0348]|3[013-589]|4[358]|6[15-7]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|7[17]|3[67]|5[05]|6[068]|1[15]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-57-9])|634|711))',
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-3])|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|0[1458]|4[08]|8[1257]|2[1-358]|1[0-478]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:[25]0|8[3-578]|7[025]|0[13]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|1(?:81|1[0-3])|(?:08|21)0))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|7[1-36]|3[013689]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|3[01479]|8[0278]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|8[03]|3[0136-9]|7[1-36]|6[0367]|2[013569]|0[25-8]|5[0-28]|1[1256])|6(?:01|7[02578]|4[04]|6[0168]|1[13-79]|2[13568]|3[01479]|8[0278]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:7[1-3]|2[01379]|3[0137-9]|6[045]|4[02-46-8]|0[2-6]|8[048]|1[01356]|5[06-8])|5(?:34|4[04]|0[13-578]|5[59]|2[0-25]|1[02579]|6[0-25-8]|8[0248]|7[267])|4(?:2[0-3]|1[1-9])|7(?:0[17]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)))',
     '143' => '(?:85(?:28|70|5[02578]|3[13589]|0[24578]|8[05]|6[0578]|4[014]|1[145]))',
@@ -143,12 +143,12 @@ our %ZIP_TABLE = (
     '150' => '(?:8(?:5(?:45|6[37]|2[25]|5[05]|8[5-8]|7[57]|1[0-24-7]|0[2357-9]|3[038])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|9[0-2]|5[24589]|7[0-46-8]|0[2-579])|6(?:7[1-7]|0[01])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
-    '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
+    '153' => '(?:8(?:5(?:6[05-7]|7[1378]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[018]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|6[05-8]|2[0135]|3[0-369]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:22|33|55|88|0[246]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
-    '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
+    '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
     '160' => '(?:8(?:3(?:41|89|3[01468]|0[14689]|1[169]|6[168]|2[147]|5[18]|7[457])|5(?:01|65|1[0-259]|4[379]|2[0-249]|3[05]|7[157]|8[0-36-9])|4(?:50|72|1[015]|2[0239]|4[47]|3[013]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[02468]|5[045]|6[689]|3[68]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[157])|0(?:22|55|0[15])|953))',
@@ -195,23 +195,23 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[167]|0[235]|5[05]|1[125])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
-    '210' => '(?:(?:8(?:5(?:2[1-3]|5[027-9]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
-    '211' => '(?:8(?:5(?:[2-4]0|66|5[058]|7[07]|8[58]|1[01]|0[125])|6(?:01|1[19]|6[68])))',
-    '212' => '(?:8(?:5(?:44|90|1[13]|0[1-389]|6[03467]|8[1-489]|2[05]|7[0267]|5[1457]|3[01])|602))',
+    '210' => '(?:(?:8(?:5(?:2[1-3]|6[0259]|5[27-9]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
+    '211' => '(?:8(?:5(?:[2-4]0|66|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|1[19]|6[68])))',
+    '212' => '(?:8(?:5(?:44|90|1[13]|6[03467]|8[1-489]|2[05]|7[0267]|5[1457]|3[01]|0[1-3589])|602))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]|4[56]))',
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
-    '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[12]))',
-    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|78|0[149]|1[1-6]|2[02]|6[08]|8[046])|7(?:11|22|65)|080|173))',
-    '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|5[058]|2[023])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
+    '216' => '(?:85(?:[56]6|01|22|70|1[0-249]))',
+    '220' => '(?:8(?:5(?:36|58|77|1[015]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:20|53|78|0[149]|1[1-6]|6[08]|8[046])|7(?:11|22|65)|080|173))',
+    '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|2[023]|5[08])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:1[025]|[58][058]|2[0-35-7]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
-    '224' => '(?:8(?:5(?:78|[18][05]|0[1-5]|5[01]|3[039]|2[024])|68[68]|730))',
+    '224' => '(?:8(?:5(?:78|8[058]|1[05]|0[1-5]|5[01]|3[039]|2[024])|68[68]|730))',
     '225' => '(?:85(?:[28]5|[56]0|13|0[1-38]|3[059]))',
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
-    '230' => '(?:8(?:5(?:11|85|7[17]|0[14]|5[05])|6(?:[01]1|[68]6|2[38])|765))',
-    '231' => '(?:8(?:5(?:[25]0|42|6[26]|3[46]|8[08])|4(?:[38]4|45|61|1[19]|7[078])|3(?:3[018]|2[0134]|1[0145])|0(?:80|0[18])|6(?:16|54|82)|7(?:11|7[12])|966))',
+    '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
+    '231' => '(?:8(?:5(?:[25]0|42|6[26]|3[46]|8[08])|3(?:43|3[018]|2[0134]|1[0145])|4(?:[38]4|45|61|1[19]|7[078])|0(?:80|0[18])|6(?:16|54|82)|7(?:11|7[12])|966))',
     '232' => '(?:8(?:5(?:15|31|76|8[057]|5[58])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:[58]8|2[23]|0[15]))',
@@ -230,17 +230,17 @@ our %ZIP_TABLE = (
     '248' => '(?:8(?:55[58]|686))',
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|39[28]|[15]92)|85(?:11|55|88)))',
-    '251' => '(?:8(?:5(?:40|2[02]|5[0158]|3[0134]|1[0135]|6[067]|8[18]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|1[01]|2[125]|5[0258]|9[2-578])|1(?:[56]2|7[27]|9[1256]|8[1-3589]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
-    '253' => '(?:(?:8(?:5(?:01|10|22|43|67|7[17]|5[058]|8[58]|3[01])|686)|019[256]))',
+    '251' => '(?:8(?:5(?:22|40|5[0158]|3[0134]|1[0135]|6[067]|8[18]|0[125])|601))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|1[01]|2[125]|5[0258]|9[2-578])|1(?:[56]2|8[13589]|7[27]|9[1256]))|0(?:3(?:7[03-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
+    '253' => '(?:(?:8(?:5(?:01|10|22|43|67|7[17]|8[58]|5[05]|3[01])|686)|019[256]))',
     '254' => '(?:8(?:5(?:43|55|67|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
     '256' => '(?:8510)',
-    '257' => '(?:8(?:5(?:11|33|55|66|2[23]|0[12]|8[4-68])|686))',
-    '258' => '(?:(?:85(?:11|85|3[38]|0[168])|0195))',
-    '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|39[26])|0(?:1(?:9[2-46-8]|8[01])|39[2356])))',
+    '257' => '(?:85(?:[23]3|11|55|66|8[458]|0[12]))',
+    '258' => '(?:(?:85(?:11|85|3[38]|0[16])|0195))',
+    '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|392)|0(?:1(?:9[2-46-8]|8[01])|39[2356])))',
     '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|2[134]|8[0568]|7[257]|0[1-9]|3[2458]|1[0-68]|5[0-24-9]|6[02-7])|7(?:3[03]|1[02357]|2[02]|0[1-37])))',
-    '261' => '(?:8(?:5(?:66|75|3[03]|4[45]|5[2458]|1[235]|2[0-2]|0[1-378]|8[125-8])|6(?:09|86)|733))',
+    '261' => '(?:8(?:5(?:66|75|3[03]|4[45]|5[2458]|1[0235]|2[0-2]|0[1-378]|8[125-8])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:36|55|0[2-468]|1[0-2])|7(?:10|33)))',
     '263' => '(?:8(?:5(?:[12]2|33|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[35]0|8[25]|0[15])|6(?:04|46)|733))',
@@ -248,10 +248,10 @@ our %ZIP_TABLE = (
     '266' => '(?:8(?:550|733))',
     '270' => '(?:(?:1(?:3(?:8[1-357]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:9[2578]|8[08])|39[23])|8(?:5(?:[0-2]1|55)|625)|019[248]))',
     '271' => '(?:8(?:5(?:01|22|33|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
-    '272' => '(?:85(?:[47]3|01|3[38]|[58][058]|2[02]|1[0-368]|6[01]))',
+    '272' => '(?:85(?:01|73|4[03]|3[38]|[58][058]|2[02]|1[0-368]|6[01]))',
     '273' => '(?:(?:8(?:5(?:7[04]|3[03]|2[0-3]|8[458]|1[0-25]|6[067]|4[023]|5[01568]|0[1-58])|6(?:01|27)|733)|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
-    '275' => '(?:8(?:5(?:[01]1|28|33|60|8[058]|7[25-7])|6(?:[01]1|66)))',
+    '275' => '(?:8(?:5(?:11|28|33|60|8[058]|7[25-7])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[34]))',
     '277' => '(?:8(?:5(?:1[158]|0[13-57]|7[07]|6[156]|5[0146-8]|8[125-9]|3[139]|2[12])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|77|5[05])|6(?:01|86)))',
@@ -259,7 +259,7 @@ our %ZIP_TABLE = (
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:[01]1|55|88)|6(?:50|86))|0195))',
     '284' => '(?:8555)',
-    '285' => '(?:8(?:5(?:33|50|67|8[0568]|0[1-39]|2[0-2]|1[01])|6(?:19|55)|765))',
+    '285' => '(?:8(?:5(?:33|50|67|8[0568]|2[0-2]|1[01]|0[1-359])|6(?:19|55)|765))',
     '286' => '(?:(?:85(?:[02]1|8[58])|029[23]))',
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
@@ -288,7 +288,7 @@ our %ZIP_TABLE = (
     '312' => '(?:85(?:11|0[1-578]))',
     '313' => '(?:8(?:6(?:[68]6|11)|511))',
     '314' => '(?:(?:8(?:501|655)|019[2-578]))',
-    '315' => '(?:(?:8(?:5(?:85|2[25]|1[1-38])|640)|0195))',
+    '315' => '(?:(?:8(?:5(?:85|2[257]|1[1-38])|640)|0195))',
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:11|55)|60[12]))',
     '318' => '(?:85[01]1)',
@@ -431,11 +431,11 @@ our %ZIP_TABLE = (
     '457' => '(?:8(?:5(?:[48]5|22|77|3[0-35]|5[158]|1[0-25]|6[067]|0[18])|71[12]))',
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:[01]1|22|40))',
-    '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|3[0-35-8]|0[1-3568]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|1[125-7]|0[1-8]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-59]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|1[0-68]|4[0135]|7[04578]|0[13-9]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
+    '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|3[0-35-8]|0[1-3568]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|1[125-7]|0[1-8]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-59]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|4[0135]|7[04578]|0[13-9]|1[0-8]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
     '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[1256])|6(?:66|80|4[015]|0[2358]|5[01458]|3[0169]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666|739))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
-    '464' => '(?:8(?:5(?:85|5[058]|4[035-7]|1[12]|6[0167]|2[0-2]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
+    '464' => '(?:8(?:5(?:85|4[05-7]|5[058]|1[12]|6[0167]|2[0-2]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])))',
     '466' => '(?:8(?:5(?:40|6[05-7]|3[39]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:73|6[06]|5[05-7]|3[035])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|2[0-25]|5[58]|1[01])|6(?:51|86|2[26]|1[015]|0[1-3]|3[39])))',
@@ -680,23 +680,23 @@ our %ZIP_TABLE = (
     '719' => '(?:(?:0(?:39[238]|19[25]|295)|3(?:19[2-57]|292)|119[23578]))',
     '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|2[024-7]|0[1-37-9])|6(?:01|50|4[0135]|3[6-9]))|039[278]|219[25]))',
     '721' => '(?:8(?:5(?:7[5-7]|6[47]|2[28]|8[568]|4[0135]|1[0145]|5[01568]|0[125])|6(?:31|88|0[17])))',
-    '722' => '(?:(?:8(?:5(?:10|0[1-35-8])|60[1245])|2(?:19[238]|49[2-4]|392)|1(?:19[23]|[47]92)|039[23]))',
+    '722' => '(?:(?:8(?:5(?:10|0[1-35-8])|60[1245])|2(?:19[238]|49[2-4]|39[23])|1(?:19[23]|[47]92)|039[23]))',
     '723' => '(?:8(?:5(?:01|20|55|1[0-25])|6(?:01|86|1[01])))',
     '725' => '(?:86[68]6)',
     '726' => '(?:8(?:6(?:28|32|1[04]|0[139])|5(?:[15]5|0[125])))',
     '727' => '(?:8501)',
     '728' => '(?:85(?:11|0[1-3]))',
-    '729' => '(?:(?:3(?:49[278]|19[23]|592)|0(?:49[25]|292|393)|2(?:39[2-5]|292)|149[23]|4295|5792))',
+    '729' => '(?:(?:3(?:49[278]|19[23]|592)|0(?:49[25]|292|393)|2(?:39[2-4]|292)|149[23]|4295|5792))',
     '730' => '(?:8(?:5(?:8[0235-9]|6[1-35-7]|4[0-358]|1[013-58]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|0[1-35689]|6[126-8]|5[0-8]|3[01]|2[026])|7(?:12|87|2[02]|3[09]|0[167]|9[4-8])))',
-    '731' => '(?:(?:0(?:19[2-7]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[2368]|29[2-4])|1(?:59[57]|795)|519[23578]|219[58]))',
+    '731' => '(?:(?:0(?:19[2-7]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[2368]|29[2-4])|1(?:59[57]|795)|519[3578]|219[58]))',
     '732' => '(?:8(?:5(?:6[4-68]|1[0-2]|0[13-57-9])|7(?:65|91)|652))',
     '733' => '(?:8(?:6(?:3[03]|2[1-6]|4[1-36-8]|7[0578]|0[18]|5[01]|6[069]|1[016])|5(?:01|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
     '734' => '(?:8(?:5(?:[37]0|22|43|58|6[07]|1[035])|798))',
     '735' => '(?:8(?:5(?:01|10|55|77|88)|6(?:70|86)))',
     '736' => '(?:8(?:5(?:55|0[124-9])|60[12]))',
-    '737' => '(?:(?:8(?:5(?:20|41|54|77|0[1-9]|1[0236-8])|6(?:09|11|86|5[0-3]))|2(?:29[235]|19[35]|39[23])|01(?:82|9[23578])))',
+    '737' => '(?:(?:8(?:5(?:20|41|54|77|0[1-9]|1[236-8])|6(?:09|11|86|5[0-3]))|2(?:29[235]|19[35]|39[23])|01(?:82|9[2358])))',
     '738' => '(?:(?:8(?:5(?:12|0[1-9])|60[1-3])|0292))',
-    '739' => '(?:(?:8(?:5(?:01|30|1[1-4]|2[124-9])|6(?:0[1-3]|1[56]))|0(?:4(?:81|9[24-7])|69[23568]|19[238]|59[25])|1(?:79[2-4]|19[25]|29[23])|2(?:49[248]|69[235])))',
+    '739' => '(?:(?:8(?:5(?:01|30|1[1-4]|2[124-9])|6(?:0[1-3]|1[56]))|0(?:4(?:81|9[24-7])|69[23568]|19[238]|59[25])|1(?:19[25]|29[23]|79[24])|2(?:49[248]|69[235])))',
     '740' => '(?:8(?:5(?:[58]5|01|67|3[35]|1[016])|6(?:11|39|86|4[26])))',
     '741' => '(?:8585)',
     '742' => '(?:(?:8(?:6(?:88|6[69]|2[25]|0[58]|4[56])|5(?:55|76|1[01])|7(?:14|87))|1(?:19[2-6]|59[28]|398)|0[34]92|219[23]))',
@@ -860,12 +860,12 @@ our %ZIP_TABLE = (
     '901' => '(?:(?:2(?:5(?:40|88|97|6[0679]|1[0-25]|5[0-35-9]|0[126]|2[0156]|3[01])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[25])|0(?:49[2-6]|19[2-4]|29[245]|39[23]|592|695)|3(?:[679]92|19[23]|59[25]|496|895)|1(?:19[2356]|39[23]|[24]92|595)))',
     '902' => '(?:85(?:21|8[58]|5[05]|1[0-2]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
-    '904' => '(?:(?:0(?:49[2-6]|19[2-5]|39[2-5]|29[35])|2(?:19[2-69]|39[2-4]|29[23])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
+    '904' => '(?:(?:0(?:49[2-6]|19[2-5]|39[2-5]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
-    '906' => '(?:(?:0[256]92|8[56]01))',
+    '906' => '(?:(?:8(?:5(?:01|50)|601)|0[256]92))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
     '910' => '(?:(?:8(?:5(?:3[0235-9]|8\d|4[013-58]|0[1-47-9]|5[0-57-9]|1[0-79]|6[0-24-8]|2[0-8]|7[15689])|6(?:22|30|6[0568]|0[136]|5[05]|8[068]|7[08]|1[01])|730)|1(?:19[2-5]|29[2-5]|392)|0(?:29[236-8]|39[23])|(?:23|3[56])92|419[35-8]))',
-    '911' => '(?:8(?:5(?:[03]1|[14]0|5[58])|601))',
+    '911' => '(?:8(?:5(?:[03]1|[14]0|85|5[58])|601))',
     '912' => '(?:(?:8(?:5(?:[58]5|24|40|67)|6[68]6)|0292))',
     '913' => '(?:8(?:5(?:[01]1|33|55|77|8[58])|611))',
     '914' => '(?:(?:8(?:5(?:[14]0|24|67|5[058]|8[05]|0[12])|6(?:09|66|8[68]))|019[258]))',
@@ -896,7 +896,7 @@ our %ZIP_TABLE = (
     '939' => '(?:(?:8(?:5(?:21|67|0[127]|[58][058]|1[0157]|7[12])|6(?:01|50|3[06]|4[02]|1[01]))|1(?:39[2-578]|89[23578]|59[2356]|69[2-48]|19[23]|99[78]|492)|0(?:29[2-6]|39[2358]|79[2358]|[15]92|693)|2(?:29[23578]|39[238]|69[24]|192|595|798)|3593))',
     '940' => '(?:(?:8(?:5(?:32|67|7[027]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2])|707)|2(?:1(?:8[1-468]|9[258])|08[1-358]|392)|029[2-8]|119[3-68]))',
     '941' => '(?:8(?:6(?:[01]1|86)|50[12]))',
-    '942' => '(?:(?:8(?:6(?:[01]1|66)|50[1258])|0(?:19[2-6]|39[238]|492)|1492))',
+    '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|1[025]|4[045]|3[0134]|2[0-25]|5[15]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
     '944' => '(?:(?:8(?:5(?:01|88|5[05])|6(?:01|86))|0192))',
     '945' => '(?:(?:8(?:5(?:[01]1|[38]5|5[58])|6(?:[01]1|88))|1(?:39[3578]|[15]95)|0(?:19[34]|39[57])))',
@@ -934,7 +934,7 @@ our %ZIP_TABLE = (
     '980' => '(?:(?:8(?:4(?:6[06]|5[2-468]|7[78]|8[014-68]|2[0-369]|1[0145]|3[013569]|0[1-3578]|4[235-8])|5(?:1[015]|4[3-6]|2[01569]|0[158]|5[05]|3[13-5]|6[0156]|7[013-9]|8[013578])|6(?:40|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|8[56]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:6(?:8[0-24-68]|9[237])|2(?:9[23568]|8[078])|1(?:9[2-5]|8[089])|49[4-7]|[35]92)|85(?:33|85|6[03]|7[07]|2[235]|5[0-25-8]|1[01]|4[035]|0[125])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|2192))',
     '982' => '(?:8(?:5(?:[03]1|44|66|77|2[13]|8[58]|5[15]|1[01])|601|798))',
-    '983' => '(?:8(?:5(?:70|3[357]|8[45]|5[156]|4[03-5]|6[05]|1[0237]|2[02378]|0[124679])|6(?:22|39|0[12])))',
+    '983' => '(?:8(?:5(?:70|4[3-5]|3[357]|8[45]|5[156]|6[05]|1[0237]|2[02378]|0[12467])|6(?:22|39|0[12])))',
     '984' => '(?:8(?:5(?:8[045]|7[057]|6[0178]|3[3589]|5[0-3578]|4[035]|2[125]|1[0-25689]|0[1-35])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
     '985' => '(?:8(?:5(?:40|89|3[1358]|2[12]|5[15]|1[01]|0[12467])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
